#!/usr/bin/env python
#
# Data Quality Checker also known as DQC
#
# Read the README.md for more detailed information
#
#       Barcelona Supercomputing Center - Centro Nacional de Supercomputacion
#       Earth Sciences Department - Computational Earth Sciences
#
#     Authors:
#       Joan Sala Calero (joan.sala@bsc.es)

import os
from ecflow import Defs, Suite, Task, Edit, Defstatus, Client

print("Creating the DQC suite definition")

# ECFLOW home directory
ecflow_home='/data/joan/c3s512-wp1-datachecker/dqc_workflow'

# ECFLOW definitions
defs = Defs(
    Suite('DQC_tasks',
          Defstatus("suspended"),
          Edit(ECF_HOME=ecflow_home, ECF_INCLUDE=ecflow_home, ECF_FILES=ecflow_home+'/tasks'),
          Task("t1"), Task("t2"), Task("t3"), Task("t4"), Task("t5")
    )
)

# ECFLOW create job
print("Checking job creation: .ecf -> .job0")
defs.check_job_creation()

print("Saving definition ...")
defs.save_as_defs("dqc_workflow.def")

# Connect to server and ping
HOST = os.getenv('ECF_HOST', 'localhost')
PORT = os.getenv('ECF_PORT', 2500)
NAME = os.getenv('SUITE', 'DQC_tasks')
ci = Client(HOST, PORT)
ci.ping()

#  Clear out the server
ci.delete_all()

# Load definition & restart
ci.load("dqc_workflow.def")
ci.restart_server()
ci.replace('%s/t1' % NAME, defs)

# start the suite
ci.begin_suite(NAME)
print(ci.stats())
print(ci.get_defs())

# We can assert, so that we only progress once job creation works
# assert len(defs.check_job_creation()) == 0, "Job generation failed"